# Frontend Development [![Awesome](https://cdn.rawgit.com/sindresorhus/awesome/d7305f38d29fed78fa85652e3a63e154dd8e8829/media/badge.svg)](https://github.com/sindresorhus/awesome)

+ Guides
    + [Bento](http://www.bentobox.io): a collection of guides for web development.
    + [Hack Design](http://hackdesign.org/courses/): An easy to follow design course for people who do amazing things.
    + [Web Style Guide - 3<sup>rd</sup> Edition](http://webstyleguide.com/wsg3/index.html) covers all the elements from CSS and typography to HTML and the structure of prose.
    + [Talks To Help You Become A Better Front-End Engineer In 2013](http://www.smashingmagazine.com/2012/12/22/talks-to-help-you-become-a-better-front-end-engineer-in-2013/)
    + [Web Development Teaching Materials](http://www.teaching-materials.org/): This site hosts a variety of CC-licensed web development curriculum which was designed to be taught, but it may be useful to students as well.
    + [Learn HTML5, CSS3, and Responsive WebSite Design in One Go](http://javascriptissexy.com/learn-html5-css3-and-responsive-web-site-design-in-one-go/)
    + [Codecademy](http://codecademy.com): Learn to code interactively, for free.
    + [Codeschool](https://www.codeschool.com/) teaches web technologies in the comfort of your browser with video lessons, coding challenges, and screencasts.
    + [TheExpressiveWeb](http://beta.theexpressiveweb.com/): This site by Adobe is a resource and showcase of some of the newest, and most expressive features being added to the web today.
    + [Treehouse](http://teamtreehouse.com/): Learn HTML, CSS, iPhone apps and more.
    + [General Assembly Dash](https://dash.generalassemb.ly): Learn HTML, CSS, and Javascript through fun projects you do in your browser.
+ Architecture
    + [Web Components](http://w3c.github.io/webcomponents/explainer/): the component model for the Web.
    + [BEM](http://bem.info/): Methodology aimed at achieving fast to develop long-lived projects, team scalability, and code reuse.
        + [Introductory article on tutsplus.com](http://webdesign.tutsplus.com/articles/an-introduction-to-the-bem-methodology--cms-19403)
        + [Introductory article on Smashing Magazine](http://www.smashingmagazine.com/2012/04/16/a-new-front-end-methodology-bem/)
        + [Video: How to use BEM! outside of Yandex](http://vimeo.com/38346573)
    + [Atomic Design](http://bradfrostweb.com/blog/post/atomic-web-design/)
        + [Slides](http://www.slideshare.net/bradfrostweb/atomic-design)
        + [Pattern Lab](http://patternlab.io/)
    + [Polymer Project](http://www.polymer-project.org/): Polymer is a library that uses the latest web technologies to let you create custom HTML elements.
    + [Flux](http://facebook.github.io/react/docs/flux-overview.html) is the application architecture that Facebook uses for building client-side web applications.
    + [Aura](http://aurajs.com/) is an event-driven architecture for developing scalable applications using reusable widgets (discontinued in favor of [Web Components](http://w3c.github.io/webcomponents/explainer/)).
    + [Hydra](http://tcorral.github.io/Hydra.js/) is an easy-to-use framework that provides you with the necessary tools to create scalable applications using modules and widgets.
    + [Terrific.js](http://terrifically.org/) provides you a Scalable JavaScript Architecture, that helps you to modularize your jQuery/Zepto Code in a very intuitive and natural way
    + [Patterns For Large-Scale JavaScript Application Architecture](http://addyosmani.com/largescalejavascript/)
    + [Building Single-Page Apps](http://nerds.airbnb.com/slides-and-video-from-spike-brehms-tech-talk/)
    + [Video: Nicholas Zakas: Scalable JavaScript Application Architecture](http://www.youtube.com/watch?v=vXjVFPosQHw)
    + [Book: Learning JavaScript Design Patterns](http://www.addyosmani.com/resources/essentialjsdesignpatterns/book/)
    + [Book: Single page apps in depth](http://singlepageappbook.com/index.html)
    + [Book: Scalable and Modular Architecture for CSS](http://smacss.com/book/)
    + [PDF: jQuery Application Architecture Chart](http://addyosmani.com/resources/toolschart/chart.pdf)
    + [How To Manage Large jQuery Apps](http://www.slideshare.net/SlexAxton/how-to-manage-large-jquery-apps)
    + [Comparison between different Observer Pattern implementations](https://github.com/millermedeiros/js-signals/wiki/Comparison-between-different-Observer-Pattern-implementations)
    + [The media object saves hundreds of lines of code](http://www.stubbornella.org/content/2010/06/25/the-media-object-saves-hundreds-of-lines-of-code)
+ Workflow
    + [Yeoman](http://yeoman.io/) is a robust and opinionated set of tools, libraries, and a workflow that can help developers quickly build beautiful, compelling web apps.
    + [Grunt](http://gruntjs.com/) is a task-based command line build tool for JavaScript projects.
        + [Web development is getting complex. Let's go shopping.](http://ruudud.github.com/2012/12/22/grunt/)
        + [GruntStart](https://github.com/tsvensen/gruntstart): A Grunt-enabled head-start with the H5BP, jQuery, Modernizr, and Respond. The building blocks to quickly get started with Grunt to create an optimized website.
        + [A beginner’s guide to Grunt](http://blog.mattbailey.co/post/45519082789/a-beginners-guide-to-grunt)
        + [Grunt - Synchronised Testing Between Browsers/Devices](http://blog.mattbailey.co/post/50337824984/grunt-synchronised-testing-between-browsers-devices)
    + [Gulp](http://gulpjs.com/) is a build system that makes use of node's streams.
        + [Gulp + Browserify: The Everything Post](http://viget.com/extend/gulp-browserify-starter-faq)
        + [The vision, history, and future of the project](https://medium.com/@eschoff/gulp-3828e8126466)
        + [Managing Your Build Tasks With Gulp.js](http://code.tutsplus.com/tutorials/managing-your-build-tasks-with-gulpjs--net-36910)
    + [Mod](https://github.com/modulejs/modjs) is a task-based workflow tooling for web, it help developers quickly build robust and high-performance web applications.
    + [Brunch](http://brunch.io/) is an assembler for HTML5 applications. It‘s agnostic to frameworks, libraries, programming, stylesheet & templating languages and backend technology.
    + [FIS](https://github.com/fex-team/fis-plus): A front-end integrated solution which included automation tool, development framework, development environment
    + [Roots](http://roots.cx/) A light, super fast, and intuitive build system meant for rapid advanced front end development.
    + [Sparky.js](http://sparkyjs.com/) is a client-side application scaffold which helps those who want to have organized structure in their app, but don't want to subscribe to a particular client-side MVC framework.
    + [Mimosa](http://mimosa.io) is a batteries included modern web development toolkit. Bower, RequireJS, Transpilers, Pre-Processors, Micro-Templating, Linting, Optimization, Serving. To start.
    + [Automaton](http://indigounited.com/automaton/): Task automation tool built in JavaScript.
    + [Cartero](https://github.com/rotundasoftware/cartero): A modular client side asset manager.
    + Front-end Process - Flat Builds and Automation
        + [Introduction](http://www.gpmd.co.uk/blog/front-end-process-flat-builds-and-automation-part-1-introduction/)
        + [Environment Setup & Yeoman](http://www.gpmd.co.uk/blog/front-end-process-flat-builds-and-automation-part-2-environment-setup-and-yeoman/)
        + [Grunt Tasks](http://www.gpmd.co.uk/blog/front-end-process-flat-builds-and-automation-part-3-grunt-tasks/)
        + [CSS Framework (Inuit)](http://www.gpmd.co.uk/blog/front-end-process-flat-builds-and-automation-part-4-css-framework/)
    + [CSSCSS](http://zmoazeni.github.io/csscss/): A CSS redundancy analyzer that analyzes redundancy.
    + [Helium](https://github.com/geuis/helium-css): JavaScript tool to scan your site and show unused CSS.
    + [JSLint](http://jslint.com/) for detecting errors or problems by static analysis of JavaScript programs.
    + [JSHint](http://jshint.com/) for more flexible static analysis of JavaScript programs.
    + [JSLint Error Explanations](http://jslinterrors.com) for explanations of the warnings given by JSLint and JSHint.
    + [ImageOptim-CLI](https://github.com/JamieMason/ImageOptim-CLI): Make lossless optimisation of images part of your automated build process.
    + [jpegoptim](https://github.com/tjko/jpegoptim): Utility to optimize/compress JPEG files.
    + [Pngcrush](http://pmt.sourceforge.net/pngcrush/) is an optimizer for PNG (Portable Network Graphics) files.
    + [Glue](https://github.com/jorgebastida/glue) is a simple command line tool to generate CSS sprites.
    + [Wraith](https://github.com/BBC-News/wraith) is a screenshot comparison tool.
    + [Penthouse](https://github.com/pocketjoso/penthouse): Critical path CSS generator.
    + [Browser-sync](https://github.com/shakyShane/browser-sync): is a tool to sync all input, scrolling, and clicking across all the devices in your testing workflow.
    + [Video: JavaScript Development Workflow of 2013 by Paul Irish](http://www.youtube.com/watch?v=f7AU2Ozu8eo) + [Slides](http://dl.dropboxusercontent.com/u/39519/talks/fluent/index.html)
+ Podcasts
	 + [Shoptalk Show](http://shoptalkshow.com/) A podcast about web design, development and UX.
	 + [Javascript Jabber](http://javascriptjabber.com/) A podcast all about Javascript
	 + [The Big Web Show](http://5by5.tv/bigwebshow) A podcast about all things web hosted by Jeffrey Zeldman
	 + [The Web Ahead](http://5by5.tv/webahead) A weekly podcast about changing technologies and the future of the web
	 + [SassCast](http://sasscast.podbean.com/) A podcast all about the Sass preprocessor.
	 + [CDNify](https://itunes.apple.com/us/podcast/cdnify/id786191888?mt=2) The CDNify podcast covers all things tech, startup, web performance and acceleration.
	 + [The Non Breaking Space Show](http://goodstuff.fm/nbsp)
+ Weekly & Daily Resources
    + [HTML5 Weekly](http://html5weekly.com/)
    + [HTML5 Bookmarks](http://html5bookmarks.com/)
    + [CSS Weekly](http://css-weekly.com/)
    + [JavaScript Weekly](http://javascriptweekly.com/)
    + [Sidebar.io](http://sidebar.io/) The 5 best design links, everyday
    + [Web Design Weekly](http://web-design-weekly.com/)
    + [Open Web Platform Daily Digest](http://webplatformdaily.org)
    + [Responsive Design Newsletter](http://responsivedesignweekly.com/)
    + [echo.js](http://www.echojs.com/): Reddit-like Website for JavaScript Resources
    + [Web Tools Weekly](http://webtoolsweekly.com/)
    + [A Drip of JavaScript](http://designpepper.com/a-drip-of-javascript)
    + [ng-newsletter](http://www.ng-newsletter.com): The free, weekly newsletter of the best AngularJS content on the web.
+ Programming & Markup Languages
    + CSS
        + [Understanding border-image](http://css-tricks.com/understanding-border-image/)
        + [What No One Told You About Z-Index](http://philipwalton.com/articles/what-no-one-told-you-about-z-index/)
        + [A Complete Guide to Flexbox](http://css-tricks.com/snippets/css/a-guide-to-flexbox/)
        + [Principles of writing consistent, idiomatic CSS](https://github.com/necolas/idiomatic-css)
        + [Github CSS Styleguide](https://github.com/styleguide/css)
        + [Wordpress CSS Coding Standards](http://make.wordpress.org/core/handbook/coding-standards/css/)
        + [Wizardry CSS Guidelines](https://github.com/csswizardry/CSS-Guidelines)
        + [Verical centering](http://codepen.io/shshaw/full/gEiDt) Cross browser absolute centering technics
        + [CSS Positioning 101](http://alistapart.com/article/css-positioning-101)
    + JavaScript
        + [Book: Eloquent JavaScript](http://eloquentjavascript.net/contents.html)
        + [Book: Speaking JavaScript](http://speakingjs.com/es5/index.html)
        + [JavaScript Study Guide](http://shiflett.org/blog/2012/apr/javascript-study-guide)
        + [JavaScript Closures](http://jibbering.com/faq/notes/closures/)
        + [OOP In JavaScript: What You NEED to Know](http://javascriptissexy.com/oop-in-javascript-what-you-need-to-know/)
        + [Combinator Recipes for Working With Objects in JavaScript](https://github.com/raganwald/homoiconic/blob/master/2012/12/combinators_1.md)
            + [Part II](https://github.com/raganwald/homoiconic/blob/master/2012/12/combinators_2.md)
        + [Prototypes and Inheritance in JavaScript](http://msdn.microsoft.com/en-us/magazine/ff852808.aspx)
        + [ECMA 262-3 in detail](http://dmitrysoshnikov.com/tag/ecma-262-3/)
        + [JavaScript Garden](http://bonsaiden.github.com/JavaScript-Garden/)
        + [Google JavaScript Style Guide](http://google-styleguide.googlecode.com/svn/trunk/javascriptguide.xml)
        + [Github JavaScript Styleguide](https://github.com/styleguide/javascript)
        + [Wordpress JavaScript Coding Standards](http://make.wordpress.org/core/handbook/coding-standards/javascript/)
        + [Structure and Interpretation of Computer Programs](http://www.comp.nus.edu.sg/~cs1101s/sicp/)
        + Extensions
            + [RubyJS](http://rubyjs.org/) is a JavaScript implementation of all methods from Ruby classes like Array, String, Numbers, Time and more.
            + [Mout](http://moutjs.com/) is a collection of modular JavaScript utilities that can be used in the browser as AMD modules or on node.js (without any overhead).
            + [bacon.js](https://github.com/raimohanska/bacon.js): A small functional reactive programming lib for JavaScript.
        + Flow Control
            + [Coroutine Event Loops in JavaScript](http://syzygy.st/javascript-coroutines/)
            + [How To Node Article on promises describing both sides: node.js and browser](http://howtonode.org/promises)
            + [Video by Douglas Crockford on monads which is touching Promises](http://www.youtube.com/watch?v=dkZFtimgAcM)
            + [Не надо давать обещания, или Promises наоборот](http://habrahabr.ru/post/166419/)
            + [Promises are the monad of asynchronous programming](http://blog.jcoglan.com/2011/03/11/promises-are-the-monad-of-asynchronous-programming/)
            + [A Study on Solving Callbacks with JavaScript Generators](http://jlongster.com/A-Study-on-Solving-Callbacks-with-JavaScript-Generators)
            + [What's The Point Of Promises?](http://www.kendoui.com/blogs/teamblog/posts/13-03-28/what-is-the-point-of-promises.aspx)
            + [Promises/A+ Spec](http://promises-aplus.github.com/promises-spec/)
            + [Callbacks vs Coroutines](https://medium.com/code-adventures/174f1fe66127)
            + [This document is intended to explain how promises work](https://github.com/kriskowal/q/blob/v1/design/README.js)
            + [Video: Monads and Gonads (YUIConf Evening Keynote)](http://youtu.be/dkZFtimgAcM)
            + Libraries
                + [Standalone-Deferred](https://github.com/warpdesign/Standalone-Deferred)
                + [Standalone-Deferred](https://github.com/Mumakil/Standalone-Deferred)
                + [Flowy](https://github.com/geeqie/node-flowy)
                + [Step](https://github.com/creationix/step)
                + [kew](https://github.com/Obvious/kew) is a lightweight promise library optimized for node.js
                + [jQuery Timing](http://creativecouple.github.com/jquery-timing/)
                + [RSVP.js](https://github.com/tildeio/rsvp.js)
                + [q](https://github.com/kriskowal/q)
                + [Watch.js](https://github.com/melanke/Watch.JS)
                + [flow.js](https://github.com/it-ony/flow.js)
    + HTML
        + [Book: Dive into HTML5](http://diveintohtml5.info/)
        + [Principles of writing consistent, idiomatic HTML](https://github.com/necolas/idiomatic-html)
        + [Google HTML/CSS Style Guide](http://google-styleguide.googlecode.com/svn/trunk/htmlcssguide.xml)
        + [Wordpress HTML Coding Standards](http://make.wordpress.org/core/handbook/coding-standards/html/)
    + Higher Level Languages
        + [Dart](http://www.dartlang.org/): Typed language compiled to JavaScript. By Google.
        + [Sass](http://sass-lang.com/) is an extension of CSS3, adding nested rules, variables, mixins, selector inheritance, and more. It’s translated to well-formatted, standard CSS using the command line tool or a web-framework plugin.
            + [Bourbon](http://bourbon.io/): A simple and lightweight mixin library for Sass.
        + [Less](http://lesscss.org/) extends CSS with dynamic behavior such as variables, mixins, operations and functions.
        + [Stylus](http://learnboost.github.io/stylus/): Expressive, dynamic, robust CSS
        + [TypeScript](http://www.typescriptlang.org/) is a typed superset of JavaScript that compiles to plain JavaScript (by Microsoft)
        + [CoffeeScript](http://coffeescript.org/) is a little language that compiles into JavaScript.
+ Frameworks
    + JavaScript
        + [Choosing a framework](http://todomvc.com/)
        + [Angular](http://angularjs.org/)
            + [Github](https://github.com/angular/angular.js)
            + Learning
                + [AngularJS-Learning](https://github.com/jmcunningham/AngularJS-Learning): huge list of Angular learning resources
                + [AngularJS Screencasts](http://www.egghead.io/)
                + [Building Huuuuuge Apps with AngularJS](http://briantford.com/blog/huuuuuge-angular-apps.html)
                + [What are the nuances of scope prototypal / prototypical inheritance in AngularJS?](http://stackoverflow.com/questions/14049480/what-are-the-nuances-of-scope-prototypal-prototypical-inheritance-in-angularjs)
                + [AngularJS from Basics to Dependency Injection](http://suhairhassan.com/2013/06/07/angularjs-in-depth-part-1.html)
                + [AngularJS To Do List App](http://www.dreamfactory.com/angularjs-example)
                + [AngularJS vs Ember](http://eviltrout.com/2013/06/15/ember-vs-angular.html)
                + [The Hitchhiker’s Guide to the Directive](http://amitgharat.wordpress.com/2013/06/08/the-hitchhikers-guide-to-the-directive/)
                + [Frontend Workflows with Grunt and Angular JS](http://youtu.be/fSAgFxjFSqY)
				+ [Angular Tips](http://angular-tips.com)
            + Integration
                + [angular-requirejs-seed](https://github.com/tnajdek/angular-requirejs-seed): this is a fork of Angular Seed but with changes needed for requireJS support.
                + [Writing Reusable AngularJS Components with Bower](http://briantford.com/blog/angular-bower.html)
                + [Native AngularJS directives for Twitter's Bootstrap.](http://angular-ui.github.io/bootstrap/)
                + [Automating AngularJS With Yeoman, Grunt & Bower](http://newtriks.com/2013/06/11/automating-angularjs-with-yeoman-grunt-and-bower/)
                + [Optimizing Angular Templates with Grunt on Heroku](http://www.codelord.net/2013/06/16/optimizing-angular-templates-with-grunt-on-heroku/)
                + [Building Offline Applications With AngularJS and PouchDB](http://mircozeiss.com/building-offline-applications-with-angularjs-and-pouchdb/)
        + [jQuery](http://jquery.com/)
            + [Github](https://github.com/jquery/jquery)
            + [jQuery Learning Center](http://learn.jquery.com/)
            + [jQuery Wiki Page "Plugins/Authoring"](http://docs.jquery.com/Plugins/Authoring)
            + [The Ultimate Guide to Writing jQuery Plugins](http://websanova.com/the-ultimate-guide-to-writing-jquery-plugins)
            + [Book: jQuery Fundamentals](http://jqfundamentals.com/)
            + [Pragmatic jQuery Style](https://github.com/modulejs/pragmatic-jquery)
            + [Handpicked jQuery Plugins](http://jque.re/)
        + [dojo](http://dojotoolkit.org/)
            + [Github](https://github.com/dojo/dojo)
            + [Documentation](http://dojotoolkit.org/documentation/)
            + [Writing Your Own Widget](http://dojotoolkit.org/reference-guide/1.9/quickstart/writingWidgets.html)
        + [Backbone](http://backbonejs.org/)
            + [Github](https://github.com/documentcloud/backbone)
            + [Book: Developing Backbone.js Applications](http://addyosmani.github.com/backbone-fundamentals/)
            + [Unsuck your backbone](https://speakerdeck.com/ammeep/unsuck-your-backbone)
            + [A Visual Guide to Marionette.js Views](http://blog.artlogic.com/2013/03/26/a-visual-guide-to-marionette-js-views/)
            + [Building a Backbone.js app](http://dailyjs.com/2012/11/29/backbone-tutorial-1/) tutorial series.
            + [Migrating an existing app to Backbone](http://www.ofbrooklyn.com/2012/11/13/backbonification-migrating-javascript-to-backbone/)
            + [Chaplin.js](http://chaplinjs.org/): An architecture for JavaScript applications using the Backbone.js library.
        + [Meteor](http://meteor.com/): An open-source platform for building top-quality web apps in a fraction of the time.
            + [Github](https://github.com/meteor/meteor)
        + [Zepto.js](http://zeptojs.com/): A minimalist JavaScript library for modern browsers with a largely jQuery-compatible API.
            + [Github](https://github.com/madrobby/zepto)
            + [Zepto Builder](http://github.e-sites.nl/zeptobuilder/) Generate a custom version of Zepto that just includes the modules you need
        + [Minified.js](http://minifiedjs.com/): Minified.js is a client-side JavaScript library, comparable to jQuery and MooTools in scope. Its features include DOM manipulation, animation, events, cookies and HTTP requests.
            + [Github](https://github.com/timjansen/minified.js/)
        + [React](http://facebook.github.io/react/) by Facebook
            + [Github](https://github.com/facebook/react)
        + [Qooxdoo](http://qooxdoo.org/) is a universal JavaScript framework for building rich, interactive application, native-like apps for mobile devices, light-weight single-page oriented web applications or even applications to run outside the browser.
        + [jQWidgets](http://www.jqwidgets.com/) is jQuery based framework and set of widgets for building web-based applications that work on PC, Touch and Mobile devices
        + [Flight](http://flightjs.github.io/) is an event-driven web framework, from Twitter
        + [Singool.js](http://fahad19.github.com/singool/) Lightweight JavaScript framework for developing single-page web applications
        + [Knockout](http://knockoutjs.com/): Simplify dynamic JavaScript UIs by applying the Model-View-View Model (MVVM) pattern
        + [rAppid.js](http://www.rappidjs.com):  a declarative (XAML) Rich Internet Application JavaScript MVC Framework
        + [Sammy.js](http://sammyjs.org/) is a tiny JavaScript framework developed to ease the pain and provide a basic structure for developing JavaScript applications.
        + [Ember.js](http://emberjs.com/): A framework for creating ambitious web applications.
        	+ [Github](https://github.com/emberjs/ember.js)
        	+ [Building an Ember.js application](https://www.youtube.com/watch?v=1QHrlFlaXdI) Walkthrough of the framework by Tom Dale, one the devs.
         	+ [EmberWatch](http://emberwatch.com/) Lots of learning ressources
        + [Maria](https://github.com/petermichaux/maria): The MVC framework for JavaScript applications. The real MVC. The Smalltalk MVC. The Gang of Four MVC.
        + [Terrific Composer](http://terrifically.org/composer/) is a Frontend Development Framework specifically designed for building deluxe frontends based on the [Terrific concept](http://terrifically.org/)
        + [Rivets.js](http://rivetsjs.com/): Lightweight and powerful data binding + templating solution for building modern web applications.
        + [Synapse](http://bruth.github.com/synapse/docs/): Data Binding For The Rest Of Us
        + [Cappuccino](http://www.cappuccino-project.org): An open source framework that makes it easy to build desktop-caliber applications that run in a web browser.
        + [A Comprehensive Collection Of JavaScript Application Frameworks](http://www.designyourway.net/blog/resources/a-comprehensive-collection-of-javascript-application-frameworks-28-examples/)
        + [JavaScript Data Binding Frameworks](http://weblogs.asp.net/dwahlin/archive/2012/07/08/javascript-data-binding-frameworks.aspx)
        + [Underscore.js](http://underscorejs.org/)
    + CSS
        + [A collection of best frameworks](http://usablica.github.io/front-end-frameworks/compare.html?v=2.0)
        + Bootstrap
            + [Home Page](http://getbootstrap.com/)
            + [GitHub](https://github.com/twbs/bootstrap/)
            + [Bootstrap Expo](http://expo.getbootstrap.com/)
            + [Bootstrap Hero List](http://www.bootstraphero.com/the-big-badass-list-of-twitter-bootstrap-resources): The big badass list of bootstrap resources
            + Widgets
                + [Bootstrap video player - jQuery plugin](http://html5-ninja.com/#/item/Bootstrap-video-player-jQuery-plugin/5): A customizable HTML5 video player plugin for jQuery based on bootstrap UI.
                + [Color and Date Picker](http://www.eyecon.ro/colorpicker-and-datepicker-for-twitter-bootstrap.htm)
                + [WYSIHTML5 RTE for Bootstrap](http://jhollingworth.github.com/bootstrap-wysihtml5/)
                + [Bootstrap Image Gallery](http://blueimp.github.com/Bootstrap-Image-Gallery/)
                + [fuelUX](http://exacttarget.github.com/fuelux/): Fuel UX extends Twitter Bootstrap with additional lightweight JavaScript controls.
                + [A date range picker for Twitter Bootstrap](http://www.dangrossman.info/2012/08/20/a-date-range-picker-for-twitter-bootstrap/)
                + [Bootbox.js](http://bootboxjs.com/): alert, confirm and flexible dialogs for Twitter's Bootstrap framework
                + [Time Picker](http://jdewit.github.com/bootstrap-timepicker/)
                + [Date/Time Picker](http://tarruda.github.com/bootstrap-datetimepicker/)
                + [ReCaptcha](http://jsfiddle.net/hqv27/)
                + [Bootstrap Modal](https://github.com/jschr/bootstrap-modal): Extends Bootstrap's native modals to provide additional functionality.
                + [SelectBoxIt](http://gregfranko.com/jquery.selectBoxIt.js)
                + [File Upload](http://jasny.github.io/bootstrap/javascript/#fileinput)
                + [BootPag](http://botmonster.com/jquery-bootpag/): BootPag - dynamic pagination jQuery plugin for twitter bootstrap
                + [Bootstrap Arrows](http://bootstrap-arrows.iarfhlaith.com/): A simple jQuery plugin and add-on to the popular Twitter Bootstrap framework to include the use of arrows at any angle in your UI designs.
                + [X-editable](http://vitalets.github.com/x-editable/): In-place editing with Twitter Bootstrap, jQuery UI or pure jQuery
                + [Pagination](https://github.com/markbates/jquery-bootstrap-pagination)
                + [Slider](http://ghusse.github.com/jQRangeSlider/)
                + [Application Wizard](https://github.com/amoffat/bootstrap-application-wizard)
            + Themes
                + [Bootswatch](http://bootswatch.com/): Theme catalog.
                + [Bootstrap Zero](http://bootstrapzero.com/): Get a less Bootstrap-y look with these custom themes
                + [Jumpstart UI](http://jumpstartui.com/): Another catalog for paid themes
                + [Themestrap](https://github.com/divshot/themestrap): A simple starter kit for constructing Twitter Bootstrap 3+ themes.
                + [jQuery Mobile Boostrap](https://github.com/commadelimited/jQuery-Mobile-Bootstrap-Theme): A jQuery Mobile theme based on Twitter Bootstrap
                + [Wrapbootstrap](http://wrapbootstrap.com/)
                + [Flat UI](http://designmodo.github.io/Flat-UI/)Free Web User Interface Kit that Rocks!
                + Wordpress
                    + [BootstrapWP](http://rachelbaker.me/bootstrapwp/)
                    + [Roots Theme](http://www.rootstheme.com/)
                    + [Bootstrap](http://digitalnature.eu/themes/bootstrap/)
                    + [Bootstrap for Wordpress](http://wpbootstrap.iubenda.com/)
                    + [Bootstrap for WP](http://envexlabs.com/2011/09/bootstrap-for-wordpress/)
                    + [StrapPress](http://braginteractive.com/bootstrap/)
                    + [WPBS](http://320press.com/wpbs/)
                + [CSS3 Microsoft Modern Buttons](http://ace-subido.github.com/css3-microsoft-metro-buttons/index.html)
                + [BootMetro](http://aozora.github.com/bootmetro/): Metro style web framework
                + [Cosmo](http://bootswatch.com/cosmo/): Windows 8 inspired theme
                + [Inspiritas](http://littke.com/2012/11/06/inspiritas-bootstrap-theme-by-ripple.html)
                + [Facebook](http://ckrack.github.com/fbootstrapp/)
                + [Google+](http://xbreaker.github.com/plusstrap/index.html)
                + [Flatstrap](http://littlesparkvt.com/flatstrap/index.html)
                + [Pinstrap](http://bragthemes.com/theme/pinstrap-pinterest-meets-bootstrap/)
            + Misc
                + [Boilerstrap](https://github.com/emorikawa/boilerstrap): A blank slate for the modern web. Just add creativity.
                + [Bootstrap GUI PSD](http://gui.repixdesign.com/#freebies): a toolkit designed to kickstart webdesign of webapps and sites.
                + [Typo3 Extension](http://typo3.org/extensions/repository/view/mn_twitter_bootstrap)
                + [Bootstrap CDN](http://www.bootstrapcdn.com/) Free CDN for Twitter Bootstrap
                + [Bootstrap Tour](http://bootstraptour.com/) Quick and easy way to build your product tours with Twitter Bootstrap Popovers.
                + [Bootsnipp](http://bootsnipp.com/): Design elements and code snippets for Bootstrap HTML/CSS/JS framework
                + [Form Builder](http://bootsnipp.com/forms)
                + [PaintStrap](http://paintstrap.com/): Generate beautiful Twitter Bootstrap themes using the Adobe kuler / COLOURlovers color scheme
                + [TODC](http://todc.github.com/todc-bootstrap/index.html): A Google-styled theme for Twitter Bootstrap.
                + [Layoutit!](http://www.layoutit.com/)
                + [Bootlint](https://github.com/twbs/bootlint): This tool checks that instances of Bootstrap components have correctly-structured HTML.
        + [IceCream](http://html5-ninja.com/icecream/): Simple and light responsive grid system.
        + [Responsive Grid System](http://responsive.gs/)
        + [Responsive Grid System (2)](http://www.responsivegridsystem.com/)
        + [Golden Grid System](http://goldengridsystem.com/)
        + [Compass](http://compass-style.org/): An open-source CSS Authoring Framework.
        + [Pondasee](http://tokokoo.github.com/pondasee/): Front-end starter kit combined with the power of SCSS & Compass.
        + [Foundation by Zurb](http://foundation.zurb.com/): The most advanced responsive front-end framework in the world.
                + [Foundation 3 Documentation](http://foundation.zurb.com/old-docs/f3/)
                + [Foundation 4 Documentation](http://foundation.zurb.com/docs/)
                + [Stylus based port](https://github.com/blai/foundation)
        + [Gumby](http://gumbyframework.com/)
        + [ProfoundGrid](http://www.profoundgrid.com/)
        + [GroundworkCSS 2](http://groundworkcss.github.io/groundwork/): A responsive HTML5, CSS & Javascript framework created and maintained by Gary Hepting
        + [Ink](http://ink.sapo.pt): Ink is a set of tools for quick development of web interfaces.
        + [neat](http://neat.bourbon.io/): A lightweight semantic grid framework for Sass and Bourbon.
        + [Kube](http://imperavi.com/kube/)
        + [rwdgrid](http://rwdgrid.com/)
        + [Simple Grid](http://thisisdallas.github.com/Simple-Grid/)
        + [One% CSS Grid](http://onepcssgrid.mattimling.com/)
        + [Workless](http://workless.ikreativ.com/)
        + [inuit.css](http://inuitcss.com/) - a powerful, scalable, Sass-based, BEM, OOCSS framework.
        + [Kraken](https://github.com/cferdinandi/kraken) is a lightweight, mobile-first boilerplate for front-end web developers.
        + [Susy](http://susy.oddbird.net/) - Responsive grids for Compass
        + [Pure](http://purecss.io/) - Minimal, flat, responsive CSS modules.
        + [Topcoat](https://github.com/topcoat/topcoat) is a CSS library evolved from the Adobe design language developed for Brackets, Edge Reflow, and feedback from the PhoneGap app developer community.
        + [Cascade Framework](http://cascade-framework.com/) - a powerful, scalable and responsive high performance OOCSS framework that supports both old and new browsers
        + [Cascade Framework Light](http://jslegers.github.io/cascadeframeworklight/) - Cascade Framework stripped down to the bare essentials, for when a minimal footprint is more important than bells and whistles
        + [Semantic UI](http://semantic-ui.com/) empowers designers and developers by creating a language for sharing UI.
+ Cross Browser
    + [Normalize.css](http://necolas.github.io/normalize.css/)
    + [HTML5 Cross Browser Polyfills](https://github.com/Modernizr/Modernizr/wiki/HTML5-Cross-browser-Polyfills)
    + [Viewport Component](https://github.com/pazguille/viewport)
    + [Can I Use](http://caniuse.com/) - Compatibility tables for support of HTML5, CSS3, SVG and more in desktop and mobile browsers.
    + [HTML5 Please](http://html5please.com/) - Collective recommendations for polyfills and implementation of HTML5 and CSS3 features.
    + [Outdated Browser](http://outdatedbrowser.com/) - Checks if user's browser is outdated and suggests downloading latest.
+ Cross Device
    + Responsive
        + [Responsive Boilerplate](http://responsiveboilerplate.com/): A starting point to responsive web design!
        + [Video: Responsive Design Workflow by Stephen Hay](http://vimeo.com/45915667) + [Slides](http://de.slideshare.net/stephenhay/mobilism2012)
        + [Responsive Patterns](http://bradfrost.github.io/this-is-responsive/patterns.html)
            + [Responsive Navigation Patterns](http://bradfrostweb.com/blog/web/responsive-nav-patterns/)
            + [Complex Navigation Patterns for Responsive Design](http://bradfrostweb.com/blog/web/complex-navigation-patterns-for-responsive-design/)
        + [Responsinator](http://www.responsinator.com/)
        + [How to make a Responsive Newspaper-like layout](http://www.newnet-soft.com/blog/responsive-multi-column)
        + [The State Of Responsive Web Design](http://mobile.smashingmagazine.com/2013/05/29/the-state-of-responsive-web-design/)
        + [Facing The Challenge: Building A Responsive Web Application](http://mobile.smashingmagazine.com/2013/06/12/building-a-responsive-web-application/)
            + [This repo contains techniques and concepts to build responsive & hybrid web applications.](https://github.com/webpro/responsive-web-apps)
        + [Am I responsive?](http://ami.responsivedesign.is/)
        + Tables
            + [Responsive Data Tables](http://css-tricks.com/responsive-data-tables/)
            + [stacktable.js](http://johnpolacek.github.com/stacktable.js/)
            + [FooTable](http://themergency.com/footable/)
        + Events
            + [Breakpoints.js](http://xoxco.com/projects/code/breakpoints/)
            + [Harvey.js](http://harvesthq.github.com/harvey/)
            + [Enquire.js](https://github.com/WickyNilliams/enquire.js)
        + Images
            + [Fluid Images](http://unstoppablerobotninja.com/entry/fluid-images/)
            + [How to Use Responsive Images to Make Your Site Shine on Any Platform](http://www.shutterstock.com/blog/2013/05/how-to-use-responsive-images-to-make-your-site-shine-on-any-platform/)
            + [Adaptive Images](http://adaptive-images.com/)
            + [Why We Need Responsive Images](http://timkadlec.com/2013/06/why-we-need-responsive-images/)
            + [Riloadr](https://github.com/tubalmartin/riloadr): A cross-browser framework-independent responsive images loader.
            + [jQuery Picture](http://jquerypicture.com/)
            + [Picturefill](https://github.com/scottjehl/picturefill)
            + [Clown Car](https://github.com/estelle/clowncar) Technique for Responsive Images
            + [imgLiquid](https://github.com/karacas/imgLiquid) jQuery plugin to resize images to fit in a container.
            + [PictureFill](https://github.com/scottjehl/picturefill)
            + [HiSRC](https://github.com/teleject/hisrc): A simple jQuery plugin for adaptive images in responsive web design
            + [resrc.it](http://www.resrc.it/): Responsive images on demand from the cloud.
        + Text
            + [FitText](http://fittextjs.com/): A jQuery plugin for inflating web type
            + [Out Of Words!](http://starburst1977.github.io/out-of-words/): The responsive typography framework behind Words App
            + [Responsive Font Sizing](http://www.newnet-soft.com/blog/responsivefontsizing): Making your font size respond to your screen size, easy & maintainable.
            + [Responsive Measure](http://jbrewer.github.com/Responsive-Measure/)
    + E-Mail
        + [Responsive Email Design](http://www.campaignmonitor.com/guides/mobile/): A great guide to create Responsive Email Design
        + [Responsive Email Templates](http://zurb.com/playground/responsive-email-templates): Some responsive templates for email
        + [Ink by Zurb](http://zurb.com/ink/): An awesome responsive email framework from the folks at Zurb.
        + [HTML Email Boilerplate](http://htmlemailboilerplate.com/)
        + [CSS Support in Email](http://www.campaignmonitor.com/css/)
        + [Email Template Reference](http://templates.mailchimp.com/)
    + Mobile
        + Frameworks
            + [jQuery Mobile](http://jquerymobile.com/): Touch-Optimized Web Framework for Smartphones & Tablets
            + [jQTouch](http://jqtouch.com/) is a Zepto/jQuery plugin for mobile web development on the iPhone, Android, iPod Touch, and other forward-thinking devices.
            + [Junior](http://justspamjustin.github.com/junior/)
        + Emulators
            + [thumbs.js](http://mwbrooks.github.com/thumbs.js/)
            + [Phantom Limb](https://github.com/brian-c/phantom-limb)
            + [Touché](https://github.com/davidcalhoun/touche)
        + Scrolling
            + [jSwipeKinetic](http://jswipekinetic.codeplex.com/) is a jQuery plugin that enables you to add kinetic scrolling on your touch optimized projects. jSwipeKinetic is build on top of jGestures (jgestues.codeplex.com).
            + [jQuery.pep.js](http://pep.briangonzalez.org/): A lightweight plugin for kinetic-drag on mobile/desktop.
            + [Overscroll](http://www.azoffdesign.com/overscroll) is a jQuery plug-in that mimics the iphone/ipad scrolling experience in a browser.
            + [Zynga Scroller](https://github.com/zynga/scroller)
            + [pull-to-refresh.js](https://github.com/dantipa/pull-to-refresh-js)
            + [Overthrow](https://github.com/filamentgroup/Overthrow)
            + [iscroll](http://cubiq.org/iscroll-4)
            + [JScrollPane](http://jscrollpane.kelvinluck.com/) is a jQuery plugin by Kelvin Luck which converts a browser's default scrollbars (on elements with a relevant overflow property) into an HTML structure.
        + Gestures
            + [jGestures](http://jgestures.codeplex.com/) jQuery plugin enables you to add gesture events such as ‘pinch’, ‘rotate’, ‘swipe’, ‘tap’ and ‘orientationchange’ just like native jQuery events.
            + [hammer.js](http://eightmedia.github.com/hammer.js/) is a focused, standalone JavaScript library, only for multi-touch gestures.
            + [TouchSwipe](https://github.com/mattbryson/TouchSwipe-Jquery-Plugin) is a jquery plugin to be used with jQuery on touch input devices such as iPad, iPhone etc.
            + [TipTap](https://github.com/marcbourlon/TipTap)
            + [jQuery.event.swipe](http://stephband.info/jquery.event.swipe/)
            + [toe.js](https://github.com/dantipa/toe.js) is a tiny library based on jQuery to enable sophisticated gestures on touch devices.
            + [Jester](https://github.com/plainview/Jester)
            + [JS Touch Layer](https://github.com/andyjamesdavies/jsTouchLayer)
            + [Touch Events and Abstractions](http://yuilibrary.com/yui/docs/event/touch.html)
        + DOM Objects Manipulation
            + [jQuery.event.move](http://stephband.info/jquery.event.move/)
        + Tap Acceleration
            + [Energize](https://github.com/davidcalhoun/energize.js)
            + [Tappable](http://cheeaun.github.com/tappable/) is a simple, standalone library to invoke the tap event for touch-friendly web browsers.
            + [Fastclick](https://github.com/ftlabs/fastclick) is a simple, easy-to-use library for eliminating the 300ms delay between a physical tap and the firing of a click event on mobile browsers.
            + [Lightning Touch](https://github.com/ucsf-ckm/LightningTouch)
            + [Creating Fast Buttons for Mobile Web Applications](https://developers.google.com/mobile/articles/fast_buttons)
        + Layout
            + [Screensizes](http://screensiz.es/)
            + [Snap.js](https://github.com/jakiestfu/Snap.js) A JavaScript Library for creating beautiful mobile shelfs in JavaScript (Facebook and Path style side menus)
            + [Flickable.js](https://github.com/tomlongo/Flickable.js) allows you to make any element touchable; useful for flicking between sections, or sliding elements around the page.
            + [Swipe](http://swipejs.com/) is a lightweight mobile slider with 1:1 touch movement, resistant bounds, scroll prevention, and completely library agnostic.
            + [Swiper](http://www.idangero.us/sliders/swiper/): Mobile touch slider with hardware accelerated transitions.
            + [jQuery Mobile Pagination Plugin](http://filamentgroup.com/lab/jquery_mobile_pagination_plugin/)
            + [SwipeSlide](https://github.com/max-power/swipeslide): A Zepto Plugin for iOS like swipe navigation.
            + [stackable.js](http://johnpolacek.github.com/stacktable.js/) is an invaluable jQuery plugin that stacks your tables for small screens. It’s a huge advantage in terms of usability on mobile devices.
        + Reacting to Device Sensors
            + [lenticular.js](http://lenticular.attasi.com/) is a jQuery plugin for creating image animations that response to tilting or mouse events.
            + [This End Up: Using Device Orientation](http://www.html5rocks.com/en/tutorials/device/orientation/)
        + iOS
            + [Safari Image Delivery Best Practices](http://developer.apple.com/library/safari/#documentation/NetworkingInternet/Conceptual/SafariImageDeliveryBestPractices/Introduction/Introduction.html#//apple_ref/doc/uid/TP40012449)
            + [Safari CSS Visual Effects Guide](http://developer.apple.com/library/safari/#documentation/InternetWeb/Conceptual/SafariVisualEffectsProgGuide/Introduction.html#//apple_ref/doc/uid/TP40008032)
            + [Safari Web Content Guide](http://developer.apple.com/library/safari/#documentation/AppleApplications/Reference/SafariWebContent/Introduction/Introduction.html#//apple_ref/doc/uid/TP40002051)
            + [Getting Started with iOS Web Apps](http://developer.apple.com/library/safari/#referencelibrary/GettingStarted/GS_iPhoneWebApp/_index.html#//apple_ref/doc/uid/TP40008134)
            + [The iPad Web Design & Development Toolbox](http://iphone.appstorm.net/roundups/developer/the-ipad-web-design-development-toolbox/)
            + [Targeting the iPhone 4 Retina Display with CSS3 Media Queries](http://blog.iwalt.com/2010/06/targeting-the-iphone-4-retina-display-with-css3-media-queries.html)
            + [How do I lock the orientation to portrait mode in a iPhone Web Application?](http://stackoverflow.com/questions/1207008/how-do-i-lock-the-orientation-to-portrait-mode-in-a-iphone-web-application)
            + [jQuery Retina Display Plugin](http://troymcilvena.com/post/998277515/jquery-retina)
            + [retina.js](http://retinajs.com/)
            + [Retina Images](http://retina-images.complexcompulsions.com/)
    + Printers
        + [Tips And Tricks For Print Style Sheets](http://coding.smashingmagazine.com/2013/03/08/tips-tricks-print-style-sheets/)
+ Patterns & Snippets
    + [Responsive Patterns](http://bradfrost.github.io/this-is-responsive/patterns.html)
    + [CSS3 Code Snippets](http://www.webinterfacelab.com/snippets/)
    + The [Blueprints](http://tympanus.net/codrops/category/blueprints/) are a collection of basic and minimal website concepts, components, plugins and layouts with minimal style for easy adaption and usage, or simply for inspiration.
+ Typography
    + [Quick guide to webfonts via @font-face](http://www.html5rocks.com/en/tutorials/webfonts/quick/)
    + [Google Fonts](http://www.google.com/fonts/)
    + [Adobe Edge Web Fonts](http://html.adobe.com/edge/webfonts/): Get started with free web fonts.
        + [Edge Web Fonts Website](https://edgewebfonts.adobe.com/fonts)
    + [Typekit](https://typekit.com/): easy way to use commercial web font on your site.
    + [Matrix of fonts bundled with Mac and Windows operating systems, Microsoft Office and Adobe Creative Suite](http://media.24ways.org/2007/17/fontmatrix.html)
    + [Typeset.css](http://joshuarudd.github.com/typeset.css/)
    + [typecast](http://beta.typecastapp.com/experiment-with-type)
    + [CSSTypography](http://tilomitra.github.io/csstypography/)
    + [SO: @font-face fonts only work on their own domain](http://stackoverflow.com/questions/2892691/font-face-fonts-only-work-on-their-own-domain)
    + [FitText](http://fittextjs.com/): A jQuery plugin for inflating web type
    + [TypeButter](http://typebutter.com/)
    + [slabText](https://github.com/freqDec/slabText/)
    + [Baseline.js](https://github.com/daneden/Baseline.js)
    + [jKerny](http://clearideaz.com/jkerny/)
    + [Lettering.js](http://letteringjs.com/)
    + [Trunk8](http://jrvis.com/trunk8/) is an intelligent text truncation plugin to jQuery. It will cut off just enough text to prevent it from spilling over
    + [bacon](http://baconforme.com/) is a jQuery plugin that allows you to wrap text around a bezier curve or a line.
    + [CSS Typography cheat sheet](http://www.newnet-soft.com/blog/csstypography): Small roundup on CSS features that will enhance your web typography.
    + [Font Squirrel Webfont Generator](http://www.fontsquirrel.com/tools/webfont-generator)
+ Services (Free & Commercial)
    + [colourco](http://colourco.de/)
    + [Color Scheme Designer](http://colorschemedesigner.com): find resonate colors for a great design.
    + [Adobe Kuler](http://kuler.adobe.com): create and share color schemes.
    + [HTML Entity Character Lookup](http://leftlogic.com/projects/entity-lookup)
    + [SpritePad](http://spritepad.wearekiss.com/)
    + [Responsinator](http://www.responsinator.com/)
    + [HTML Shell](http://htmlshell.com/)
    + [Form Builder](http://livetools.uiparade.com/form-builder.html)
    + [Zen BG](http://mudcu.be/bg/)
    + [What Font Is](http://www.whatfontis.com/) identifies fonts from an image.
    + [Prepros](http://alphapixels.com/prepros/)
    + [Browser Shots](http://browsershots.org/) tests compatibility in almost every browser.
    + [CSSArrowPlease](http://cssarrowplease.com) Simple tooltip arrows with CSS
    + [jsFiddle](http://jsfiddle.net)
    + [CodePen](http://codepen.io/) is an HTML, CSS, and JavaScript code editor right in your browser with instant previews of the code you see and write.
    + [site44](https://www.site44.com/) turns Dropbox folders to websites
    + [JPEGmini Photo Server](http://www.jpegmini.com/server) is an image optimization server which runs on Amazon EC2 (commercial).
    + [TinyPNG](http://tinypng.org/): Advanced lossy compression for PNG images that preserves full alpha transparency.
    + [GenyMotion](http://www.genymotion.com/) is the next generation of the AndroVM open source project, already trusted by 900,000 developers.
    + [Website Builders](http://en.wikipedia.org/wiki/Website_builder)
        + [Squarespace](http://www.squarespace.com/)
        + [BaseKit](http://www.basekit.com/)
        + [Doomby](http://www.doomby.com/)
        + [Edicy](http://www.edicy.com/)
        + [IM Creator](http://imcreator.com/)
        + [Jimdo](http://www.jimdo.com/)
        + [Moonfruit](http://www.moonfruit.com/)
        + [uCoz](http://www.ucoz.com/)
        + [Webnode](http://www.webnode.com)
        + [Webs](http://www.webs.com/)
        + [Weebly](http://www.weebly.com/)
        + [Wix](http://www.wix.com)
        + [Wordpress.com](http://wordpress.com/)
        + [Yola](https://www.yola.com/)
        + [1&1 Homepage](http://homepage.1und1.de/)
+ Animation
    + [Velocity.js](http://velocityjs.org): Re-implementation of jQuery's $.animate() that adds 20x the speed while also drastically improving the UI animation workflow.
    + [Animo.js](http://labs.bigroomstudios.com/libraries/animo-js): A powerful little tool for managing CSS animations
    + [Stylie](http://jeremyckahn.github.com/stylie/)
    + [animate.less](https://github.com/machito/animate.less), is a bunch of cool, fun, and cross-browser animations converted into LESS for you to use in your Bootstrap projects. Great for emphasis, home pages, sliders, and general just-add-water-awesomeness.
    + [Canvas Advanced Animation Toolkit](http://hyperandroid.github.com/CAAT/) is an scene graph director-based animation framework for javascript based in the concept of a timeline.
    + [tween.js](https://github.com/sole/tween.js): Super simple, fast and easy to use tweening engine which incorporates optimised Robert Penner's equations.
    + [Janis](https://github.com/MikeMcTiernan/Janis) is a lightweight JavaScript framework that provides simple animations via CSS transitions for modern browsers on the web as well as mobile devices.
    + [Rekapi](http://rekapi.com/): A keyframe animation library for JavaScript
    + [CanvasScript3](http://www.arahaya.com/canvasscript3/) is a JavaScript library for the new HTML5 Canvas with an interface similar to ActionScript3. This library enables Sprite Groups, Layers, Mouse Events, Keyboard Events, Bitmap Effects, Tween Animations etc.
    + [Shifty](http://jeremyckahn.github.com/shifty/) is a tweening engine built in JavaScript.  It is designed to fit any number of tweening needs.
    + [emile.js](https://github.com/madrobby/emile) is a no-frills stand-alone CSS animation JavaScript framework.
    + [Firmin](http://extralogical.net/projects/firmin/): a JavaScript animation library using CSS transforms and transitions.
    + [Keanu](https://github.com/wambotron/Keanu) is a micro-lib for animation on Canvas/JS.
    + [jsAnim](http://jsanim.com/) is a powerful, yet easy to use library for adding impressive animations to websites, without sacrificing standards or accessibility. Weighing in at just under 25 kilobytes, jsAnim packs a lot of punch for such a little application.
    + [GreenSock Animation Platform](http://www.greensock.com/get-started-js/) is a suite of tools for scripted animation.
        + [Learning Resources](http://www.greensock.com/learning/)
        + [Examples](http://ahrengot.com/tutorials/greensock-javascript-animation/)
        + [Codepen Repository](http://codepen.io/GreenSock/): Codepen repository with examples of Greensock usage and code
    + [scripty2](http://scripty2.com/) is an open source JavaScript framework for advanced HTML-based user interfaces. Or simply put, scripty2 helps you build a more delicious web.
    + [Animator.js](http://berniesumption.com/software/animator/): JavaScript animation library.
    + [Processing.js](http://processingjs.org/):  is the sister project of the popular Processing visual programming language, designed for the web. Processing.js makes your data visualizations, digital art, interactive animations, educational graphs, video games, etc. work using web standards and without any plug-ins.
    + [jQuery Transit](http://ricostacruz.com/jquery.transit/): Super-smooth CSS3 transformations and transitions for jQuery.
    + [Move.js](http://visionmedia.github.com/move.js/) is a small JavaScript library making CSS3 backed animation extremely simple and elegant.
    + [Collie](http://jindo.dev.naver.com/collie/) is a JavaScript library that helps to create highly optimized animations and games using HTML 5.
    + [Year Of Moo](http://www.yearofmoo.com/): Angular.js Animations
    + [animate.css](http://daneden.me/animate/) is a bunch of cool, fun, and cross-browser animations for you to use in your projects. Great for emphasis, home pages, sliders, and general just-add-water-awesomeness.
    + [Approach](http://srobbin.com/jquery-plugins/approach/)
    + [Magic](https://github.com/miniMAC/magic) is a CSS3 framework with many animations, it's simple to use and many animations are cross-browser compatible.
+ Widgets
    + Kits
        + [AlloyUI](http://liferay.github.com/alloyui.com/)
        + [Kendo UI](http://www.kendoui.com/)
        + [jQuery UI Bootstrap](http://jquery-ui-bootstrap.github.io/jquery-ui-bootstrap/): Bootstrap theme for jQuery UI
        + [jQuery Bootstrap](https://github.com/jslegers/jquery-bootstrap): Integration of Bootstrap and jQuery UI
        + [Cascade Framework](http://cascade-framework.com/): high performance widgets allow you to define the UI status directly in the DOM
        + [Zebra](http://zebra.gravitysoft.org/): JavaScript library that follows easy OOP concept, provides HTML5 Canvas based Rich UI and includes Java to JavaScript converter tool
    + File Upload
        + [jQuery File Upload](http://blueimp.github.com/jQuery-File-Upload/)
        + [tus fileupload](http://www.tus.io/)
        + [Fine Uploader](http://fineuploader.com/)
        + [finderSelect](http://evulse.github.io/finderSelect/)
    + Sitemap
        + [SlickMap CSS](http://astuteo.com/slickmap)
    + Table Of Contents
        + [Tocify](http://gregfranko.com/jquery.tocify.js)
        + [MagicNav.js](http://johnpolacek.github.com/MagicNav.js/)
        + [jQuery TOC](http://projects.jga.me/toc/)
    + Modals
        + [Avgrund](http://lab.hakim.se/avgrund/)
        + [Timeout Dialog](http://rigoneri.github.com/timeout-dialog.js/)
        + [Magnific Popup](http://dimsemenov.com/plugins/magnific-popup/)
        + [Zoombox](http://grafikart.github.io/Zoombox/)
    + Notifications
        + [notifier.js](https://github.com/Srirangan/notifer.js)
        + [noty](http://needim.github.com/noty/)
        + [Toastr](http://codeseven.github.com/toastr/)
        + [alertify.js](http://fabien-d.github.com/alertify.js/)
        + [Apprise](http://thrivingkings.com/read/Apprise-v2-The-new-and-improved-attractive-alert-alternative-for-jQuery)
    + Gallery Sliders
        + [Sequence](http://www.sequencejs.com/)
        + [Rhinoslider](http://rhinoslider.com/)
        + [Awkward Showcase](http://www.awkwardgroup.com/sandbox/awkward-showcase-a-jquery-plugin/)
        + [Responsive CSS3 Slider](http://csscience.com/responsiveslidercss3/)
        + [Roundabout](http://fredhq.com/projects/roundabout/)
        + [Slid.es](http://slid.es/)
        + [Galleria](http://galleria.io/)
    + Pagination
        + [jPages](http://luis-almeida.github.com/jPages/)
    + Selects
        + [jQuery Recurrence Input](https://github.com/collective/jquery.recurrenceinput.js)
        + [Select2](http://ivaynberg.github.com/select2/)
        + [jquery.selectable.js](http://endel.github.com/jquery.selectable.js/)
        + [chosen](https://github.com/harvesthq/chosen) is a library for making long, unwieldy select boxes more friendly.
    + Progress Bars
        + [Percentage Loader](http://widgets.better2web.com/loader/)
        + [progress.js](https://github.com/mdix/progress.js)
    + Trees
        + [Nestable](http://dbushell.com/2012/06/17/nestable-jquery-plugin/)
    + Navigation
        + [jPanelMenu](http://jpanelmenu.com)
    + Tooltips
        + [opentip](http://www.opentip.org/)
    + Misc
        + [jQuery Knob](http://anthonyterrien.com/knob/)
        + [DopelessRotate](http://www.dopeless-design.de/dopeless-rotate-jquery-plugin-360-degrees-product-viewer.html)
        + [jQuery Addresspicker](http://mngscl-10.s3-website-us-east-1.amazonaws.com/jquery-addresspicker-bootstrap/demos/index.html)
        + [Fangle](http://jotux.github.io/fangle/): create interactive documents from plain text.
        + [Skeucard](http://kenkeiter.com/skeuocard/) progressively enhances credit card inputs to provide a skeuomorphic interface.
+ Visualization
    + [Photon](https://github.com/thomasxiii/photon)
    + [Morris.js](https://github.com/morrisjs/morris.js/)
    + [Cube](http://square.github.com/cube/)
    + [Cubism.js](http://square.github.com/cubism/)
    + [D3.js](http://d3js.org/)
        + [Introduction to D3](http://www.janwillemtulp.com/2011/03/20/tutorial-introduction-to-d3/)
        + [Interactive D3 Tutorial](http://vogievetsky.github.com/IntroD3/)
        + [NVD3](http://nvd3.org/)
        + [Vega](http://trifacta.github.io/vega/)
    + [Crossfilter](http://square.github.com/crossfilter/)
    + [Datavisualization.ch](http://selection.datavisualization.ch/)
    + [jQuery.Gantt](http://taitems.github.com/jQuery.Gantt/)
    + [easy pie chart](http://rendro.github.com/easy-pie-chart/)
    + [JointJS JavaScript Diagramming Library](http://jointjs.com/)
    + [Gauge.js](http://bernii.github.com/gauge.js/)
    + [Google Chart Tools](https://developers.google.com/chart/)
    + [Piecon](http://lipka.github.com/piecon/)
    + [Viskit.js](http://wso2.github.com/viskit/)
    + [jStat](http://www.jstat.org/)
    + [CHAP Links Library](http://almende.github.com/chap-links-library/index.html)
    + [bonsai](http://bonsaijs.org/)
    + [Smoothie Charts](http://smoothiecharts.org/)
    + [DataMaps](http://datamaps.github.com/)
    + [mxgraph](http://jgraph.github.io/mxgraph/)
    + [Paper.js](http://paperjs.org) is an open source vector graphics scripting framework that runs on top of the HTML5 Canvas.
    + [Timeline.js](https://github.com/VeriteCo/TimelineJS): A Storytelling Timeline built in JavaScript.
    + [xCharts](http://tenxer.github.com/xcharts/) is a JS library for creating attractive, custom data-driven chart visualizations. It uses HTML, CSS, and SVG to create dynamic, fluid charts that can be easily customized and integrated.
    + [jQuery Gantt editor](http://roberto.open-lab.com/2013/01/28/jquery-gantt-editor-include-today/)
    + [amCharts](http://www.amcharts.com/) is a robust charting tool that will suit any dataviz need.
    + [Raphael.js](http://raphaeljs.com/) Easy vector graphics for the web.
    + [three.js](http://threejs.org) JavaScript 3D library.
    + [Highcharts](http://www.highcharts.com/): Interactive JavaScript Charts for your web projects.
    + [Flot](http://www.flotcharts.org/): Attractive JavaScript plotting for jQuery
    + [Chart.js](http://www.chartjs.org/): Easy, object oriented client side graphs for designers and developers
    + [GoJS](http://gojs.net): Library for creating interactive diagrams (Trees, flowcharts, state charts, etc) in the browser.
    + [JointJS](http://jointjs.com/) is a modern HTML 5 JavaScript library for visualization and interaction with diagrams and graphs.
+ Validation & Forms
    + [Mention.js](https://github.com/jakiestfu/Mention.js) Lightweight wrapper for adding @user mention functionality to Twitter Bootstraps Typeahead plugin
    + [ALAJAX](http://www.alajax.com/)
    + [Parsley.js](http://parsleyjs.org): Validate your forms, frontend, without writing a single line of javascript!
    + [mailcheck.js](https://github.com/Kicksend/mailcheck): A jQuery plugin that suggests a right domain when your users misspell it in an email address.
    + [one-validation](https://github.com/One-com/one-validation) is a collection of regular expressions for general validation purposes.
    + [nextVal](http://jukebox42.github.com/nextVal/) is an easy-to-use, flexible and robust form validation plugin for jQuery.
    + [Fields.js](http://schneiderik.github.com/fields/) creates collections of fields. Each field is constantly evaluated for validity, and is accessible through the collection.
    + [IV.js](http://dadleyy.github.com/IV.js/) was created to provide a intutive way to provide validation filters that are useful in processing user input.
    + [Ladda](http://lab.hakim.se/ladda/): A UI concept which merges loading indicators into the action that invoked them.
    + [jQuery Super Labels](http://remy.bach.me.uk/superlabels_demo/)
    + [jQuery Validation Engine](http://www.position-relative.net/creation/formValidator/): jQuery validation engine is a JavaScript plugin aimed at the validation of form fields in the browser
+ Transitions
    + [Quicksand](http://razorjack.net/quicksand/)
    + [Isotope](http://isotope.metafizzy.co/)
    + [flippant.js](http://mintchaos.github.io/flippant.js/)
+ Numbers
    + [numeral.js](http://numeraljs.com/): A javascript library for formatting and manipulating numbers.
    + [accounting.js](http://josscrowcroft.github.com/accounting.js/)
    + [numbers.js](https://github.com/sjkaliski/numbers.js)
+ Time and Dates
    + [moment.js](http://momentjs.com/): A 5.5kb javascript date library for parsing, validating, manipulating, and formatting dates.
    + [XDate](http://arshaw.com/xdate/)
    + [Pikaday](https://github.com/dbushell/Pikaday)
+ Search
    + [Fullproof](http://reyesr.github.com/fullproof/)
    + [lunr.js](http://lunrjs.com/) is a simple full text search engine for your client side applications.
+ Testing
    + [BrowserStack] (http://www.browserstack.com/start) Comprehensive range of Browsers & Mobile Emulators available online for Live Testing and ready to use.
    + [FiveUI](http://galoisinc.github.io/FiveUI/) Extensible/open browser extension & headless system for testing UI Consistency guidelines (or anything else you can test with injected JS).
    + [Writing Testable JavaScript](http://alistapart.com/article/writing-testable-javascript)
    + [Writing Testable Frontend JavaScript Part 1 – Anti-patterns and their fixes](https://shanetomlinson.com/2013/testing-javascript-frontend-part-1-anti-patterns-and-fixes/)
    + [Introduction to BDD](http://dannorth.net/introducing-bdd/)
    + [cucumber](https://github.com/cucumber/cucumber/wiki)
        + [cucumber.js](https://github.com/cucumber/cucumber-js)
        + [Gherkin](https://github.com/cucumber/cucumber/wiki/Gherkin) is the language that Cucumber understands.
            + [Feature Introduction](https://github.com/cucumber/cucumber/wiki/Feature-Introduction)
            + [Given when then](https://github.com/cucumber/cucumber/wiki/Given-When-Then)
    + [Jasmine](http://jasmine.github.io/) - JavaScript BDD testing framework with Rspec-like syntax
    + [QUnit](http://qunitjs.com/) - JavaScript unit testing framework
    + [JsMockito](http://jsmockito.org/) - JavaScript stub/mock framework heavily inspired by Mockito
    + [PhantomCSS](https://github.com/Huddle/PhantomCSS) - for automating visual regression testing of website styling to support refactoring of CSS
    + [Gemini](https://github.com/bem/gemini) - Utility for regression testing of web pages using screenshots
    + [Karma](http://karma-runner.github.io/) - Spectacular Test Runner for JavaScript
    + [Chai Assertion Library](http://chaijs.com/) - Chai is a BDD / TDD assertion library for node and the browser that can be delightfully paired with any javascript testing framework.
    + [Sinon.JS](http://sinonjs.org/) - Standalone test spies, stubs and mocks for JavaScript.
    + [sinon-chai](https://github.com/domenic/sinon-chai) - Extends Chai with assertions for the Sinon.JS mocking framework.
    + [PhantomJS](http://phantomjs.org/) - PhantomJS is a headless WebKit, scriptable with a JavaScript API
    + [SlimerJS](http://slimerjs.org/) - A scriptable browser for Web developers that runs on Gecko
+ Template Engines
    + [ICanHaz.js](http://icanhazjs.com/)
    + [Hogan.js](http://twitter.github.com/hogan.js/)
    + [Handlebars.js](http://handlebarsjs.com/): Minimal Templating on Steroids
    + [Mustache](http://mustache.github.io/): Logic-less templates
    + [Transparency](http://leonidas.github.com/transparency/)
    + [doT.js](http://olado.github.com/doT/)
    + [Walrus](http://documentup.com/jeremyruppel/walrus/)
    + [Chibi](https://github.com/kylebarrow/chibi)
    + [Templayed.js](http://archan937.github.com/templayed.js/)
    + [ECT](http://ectjs.com/): Fastest JavaScript template engine with CoffeeScript syntax
    + [pithy](https://github.com/caolan/pithy): An internal DSL for generating HTML in JavaScript
    + [T](https://github.com/gcao/T.js): T.js is a template engine that uses simple JavaScript data structure to represent html/xml data.
    + [Nunjucks](http://nunjucks.jlongster.com/) is a full featured templating engine for javascript.
    + [Jade](http://jade-lang.com/)
    + [Linked.in Dust.js](http://linkedin.github.com/dustjs/)
        + [The client-side templating throwdown: mustache, handlebars, dust.js, and more](http://engineering.linkedin.com/frontend/client-side-templating-throwdown-mustache-handlebars-dustjs-and-more)
        + [Leaving JSPs in the dust: moving LinkedIn to dust.js client-side templates](http://engineering.linkedin.com/frontend/leaving-jsps-dust-moving-linkedin-dustjs-client-side-templates)
        + [Tutorial](https://github.com/linkedin/dustjs/wiki/Dust-Tutorial)
        + [Testing Console](http://linkedin.github.com/dustjs/test/test.html)
+ Routing And URLs
    + [Crossroads.js](http://millermedeiros.github.com/crossroads.js/)
    + [Hash.js](https://github.com/javve/hash.js)
    + [director](https://github.com/flatiron/director)
    + [Davis.js](http://davisjs.com/)
    + [path.js](http://mtrpcic.github.com/pathjs/)
    + [URI.js](http://medialize.github.com/URI.js/)
    + [Roadcrew.js](http://grobmeier.github.com/Roadcrew.js/)
    + [jQuery Address](http://www.asual.com/jquery/address/)
    + [page.js](https://github.com/visionmedia/page.js)
    + [speakingurl](https://github.com/pid/speakingurl): generate a so called "static", "Clean URL", "Pretty URL" or "slug" from a string.
+ Rich Text Editors
    + [Mercury](http://jejacks0n.github.io/mercury/)
    + [Redactor](http://imperavi.com/redactor/)
    + [WYSIHTML5](http://xing.github.com/wysihtml5/)
    + [MarkItUp](http://markitup.jaysalvat.com/)
    + [Hallo](http://hallojs.org/)
    + [Substance Composer](https://github.com/substance/composer)
    + [Proper](https://github.com/michael/proper)
    + [SnapEditor](http://www.snapeditor.com/)
    + [Create.js](http://createjs.org/)
    + [MDMagick](http://fguillen.github.com/MDMagick/)
    + [X-editable](http://vitalets.github.com/x-editable/)
+ Code Viewers & Editors
    + [SublimeText](http://sublimetext.com/)
    + [Rainbow.js](http://craig.is/making/rainbows)
    + [Intelligist](http://srobbin.com/jquery-plugins/intelligist/)
    + [Prism.js](http://prismjs.com/)
    + [Brackets](https://github.com/adobe/brackets): An open source code editor for the web, written in JavaScript, HTML and CSS by Adobe.
    + [CodeMirror](http://codemirror.net/)
    + [Scripted](https://github.com/scripted-editor/scripted)
    + [tabIndent.js](http://julianlam.github.com/tabIndent.js/)
    + [Behave.js](http://jakiestfu.github.io/Behave.js/) is a lightweight library for adding IDE style behaviors to plain text areas, making it much more enjoyable to write code in.
+ Refactoring
    + [Refactoring JavaScript with kratko.js](http://perfectionkills.com/refactoring-javascript-with-kratko-js/)
+ Performance
    + General Information
        + [Video: DOM, HTML5, & CSS3 Performance](http://paulirish.com/2011/dom-html5-css3-performance/) by Paul Irish
        + [Video: High Performance JavaScript](http://vimeo.com/16241085) by Nicholas Zakas
        + [Video: Building A Performant HTML5 App](http://youtu.be/ft9R72R7TlI) with Trunal Bhanse and Akhilesh Gupta (LinkedIn)
        + [Writing Fast, Memory-Efficient JavaScript](http://coding.smashingmagazine.com/2012/11/05/writing-fast-memory-efficient-javascript/)
        + [JavaScript Performance Best Practices](http://www.developer.nokia.com/Community/Wiki/JavaScript_Performance_Best_Practices) by Nokia
        + [Improving the performance of your HTML5 App](http://www.html5rocks.com/en/tutorials/speed/html5/)
        + [Best Practices for a Faster Web App with HTML5](http://www.html5rocks.com/en/tutorials/speed/quick/)
        + [Front-end performance for web designers and front-end developers](http://csswizardry.com/2013/01/front-end-performance-for-web-designers-and-front-end-developers/)
        + [Let's Make the Web Jank-free!](http://jankfree.org/)
    + Memory
        + [Memory Analysis 101](https://developer.chrome.com/devtools/docs/memory-analysis-101)
        + [Memory leak patterns in JavaScript](https://www.ibm.com/developerworks/library/wa-memleak/)
        + [Understanding and Solving Internet Explorer Leak Patterns](http://msdn.microsoft.com/en-us/library/bb250448.aspx)
        + [Finding memory leaks](http://gent.ilcore.com/2011/08/finding-memory-leaks.html)
        + [How to write low garbage real-time JavaScript](https://www.scirra.com/blog/76/how-to-write-low-garbage-real-time-javascript)
        + [JScript Memory Leaks](http://javascript.crockford.com/memory/leak.html)
        + [Tracking Down Memory Leaks in Node.js](https://hacks.mozilla.org/2012/11/tracking-down-memory-leaks-in-node-js-a-node-js-holiday-season/)
        + [Effectively Managing Memory at Gmail scale](http://www.html5rocks.com/en/tutorials/memory/effectivemanagement/)
        + [Writing Fast, Memory-Efficient JavaScript](http://coding.smashingmagazine.com/2012/11/05/writing-fast-memory-efficient-javascript/)
    + Tools
        + [jsPerf, the JavaScript performance playground](http://jsperf.com/)
        + [Chrome Developer Tools](https://developers.google.com/chrome-developer-tools/)
            + [Heap Profiling](https://developers.google.com/chrome-developer-tools/docs/heap-profiling)
            + [Profiles Panel](https://developers.google.com/chrome-developer-tools/docs/profiles)
            + [JavaScript Profiling With The Chrome Developer Tools](http://coding.smashingmagazine.com/2012/06/12/javascript-profiling-chrome-developer-tools/)
            + [Introduction to Chrome Developer Tools, Part One](http://www.html5rocks.com/en/tutorials/developertools/part1/)
            + [Revolutions 2013](http://www.html5rocks.com/en/tutorials/developertools/revolutions2013/)
        + V8
            + [Optimizing for V8](http://floitsch.blogspot.co.uk/search/label/V8) - very technical series on the V8 engine
            + [I-want-to-optimize-my-JS-application-on-V8 checklist](http://mrale.ph/blog/2011/12/18/v8-optimization-checklist.html)
            + [Performance tips for JavaScript in V8](http://www.html5rocks.com/en/tutorials/speed/v8/)
        + [JavaScript Leak Finder](http://code.google.com/p/leak-finder-for-javascript/)
            + [Introduction Article](http://google-opensource.blogspot.de/2012/08/leak-finder-new-tool-for-javascript.html)
        + [Navigation Timing](http://www.html5rocks.com/en/tutorials/webperformance/basics/)
        + [Firebug Paint Events](https://addons.mozilla.org/en-US/firefox/addon/firebug-paint-events/)
        + [Locache](https://github.com/d0ugal/locache): JavaScript caching framework for client side caching in the browser using localStorage
        + [Caliper](http://caliper.io/) is a web service for performance monitoring of your web app.
    + DOM Manipulation
        + [Rendering: repaint, reflow/relayout, restyle](http://www.phpied.com/rendering-repaint-reflowrelayout-restyle/)
        + [Reflows & Repaints: CSS Performance making your JavaScript slow?](http://www.stubbornella.org/content/2009/03/27/reflows-repaints-css-performance-making-your-javascript-slow/)
        + [The new game show: "Will it reflow?"](http://calendar.perfplanet.com/2009/the-new-game-show-will-it-reflow/)
        + [When does reflow happen in a DOM environment?](http://stackoverflow.com/questions/510213/when-does-reflow-happen-in-a-dom-environment)
        + [Speeding up JavaScript: Working with the DOM](https://developers.google.com/speed/articles/javascript-dom)
        + [When Does JavaScript trigger reflows and rendering](http://mir.aculo.us/2010/08/17/when-does-javascript-trigger-reflows-and-rendering/)
        + [How (not) to trigger a layout in WebKit](http://gent.ilcore.com/2011/03/how-not-to-trigger-layout-in-webkit.html)
    + Animation
        + [requestAnimationFrame for smart animating](http://paulirish.com/2011/requestanimationframe-for-smart-animating/)
        + [Leaner, Meaner, Faster Animations with requestAnimationFrame](http://www.html5rocks.com/en/tutorials/speed/animations/)
        + [Collie - high performance Animation library](http://jindo.dev.naver.com/collie/)
        + [requestAnimationFrame API: now with Sub-Millisecond Precision](http://updates.html5rocks.com/2012/05/requestAnimationFrame-API-now-with-sub-millisecond-precision)
        + [Why moving elements with translate() is better than pos:abs top/left](http://paulirish.com/2012/why-moving-elements-with-translate-is-better-than-posabs-topleft/)
    + Hardware Acceleration
        + [Visualizing WebKit’s hardware acceleration](http://mir.aculo.us/2011/02/08/visualizing-webkits-hardware-acceleration/)
        + [List of Chromium Command Line Switches](http://peter.sh/experiments/chromium-command-line-switches/)
    + Browser Internals
        + [Video: Google I/O 2012 - Breaking the JavaScript Speed Limit with V8](http://www.youtube.com/watch?v=UJPdhx5zTaw) by Daniel Clifford
        + [Video: Faster HTML and CSS: Layout Engine Internals for Web Developers](http://www.youtube.com/watch?v=a2_6bGNZ7bA): by David Baron of Mozilla
        + [How Browsers Work: Behind the scenes of modern web browsers](http://www.html5rocks.com/en/tutorials/internals/howbrowserswork/)
        + [Know Your Engines at O’Reilly Velocity 2011](https://blog.mozilla.org/dmandelin/2011/06/16/know-your-engines-at-oreilly-velocity-2011/)
        + [Video: GDC 2012: From Console to Chrome](http://www.youtube.com/watch?v=XAqIpGU8ZZk)
        + [Fast CSS: How Browsers Lay Out Web Pages](http://dbaron.org/talks/2012-03-11-sxsw/master.xhtml)
        + [Video: What Browsers Really Think of Your App](http://dayofjs.com/videos/22158462/web-browsers_alex-russel)
        + [WebKit blog five-part series on rendering](https://www.webkit.org/blog/114/webcore-rendering-i-the-basics/)
        + [Video: Alex Russell - Life Of A Button Element](http://vimeo.com/32364192)
        + [How a web page loads](http://gent.ilcore.com/2011/05/how-web-page-loads.html)
        + [Video: The Fundamentals, Primitives and History of HTML5](http://paulirish.com/2011/primitives-html5-video/)
        + [The JavaScript engine family tree](http://creativejs.com/2013/06/the-race-for-speed-part-1-the-javascript-engine-family-tree/)
        + [How JavaScript compilers work](http://creativejs.com/2013/06/the-race-for-speed-part-2-how-javascript-compilers-work/)
        + [JavaScript compiler strategies](http://creativejs.com/2013/06/the-race-for-speed-part-3-javascript-compiler-strategies/)
        + [The future for JavaScript](http://creativejs.com/2013/06/the-race-for-speed-part-4-the-future-for-javascript/)
    + Images
        + [CSS-only: Load images on demand](http://podlipensky.com/2013/06/css-only-load-images-on-demand/)
        + [Clever JPEG Optimization Techniques](http://www.smashingmagazine.com/2009/07/01/clever-jpeg-optimization-techniques/)
        + [Clever PNG Optimization Techniques](http://www.smashingmagazine.com/2009/07/15/clever-png-optimization-techniques/)
        + [How to Optimize PNG and JPEG without Quality Loss](http://www.splashnology.com/article/how-to-optimize-png-and-jpeg-without-quality-loss-part-1/2071/) + [Part 2](http://www.splashnology.com/article/how-to-optimize-png-and-jpeg-without-quality-loss-part-2/2568/)
    + HTTP Transport
        + [Fantastic front-end performance: Concatenate, Compress & Cache](https://hacks.mozilla.org/2012/12/fantastic-front-end-performance-part-1-concatenate-compress-cache-a-node-js-holiday-season-part-4/)
        + [Video: Cache Is King!](http://www.youtube.com/watch?v=HKNZ-tQQnSY) by Steve Souders
        + [Best Practices for Speeding Up Your Web Site](http://developer.yahoo.com/performance/rules.html) by Yahoo
+ Modularity & Loaders
    + [Lazy Module Declaration](http://lmdjs.org/): JavaScript Module-Assembler for building better web applications
    + [UMD (Universal Module Definition) patterns](https://github.com/umdjs/umd)
    + [Browserify](http://browserify.org/)
    + [require.js](http://requirejs.org/)
        + [Plugins](https://github.com/jrburke/requirejs/wiki/Plugins)
    + [sea.js](http://seajs.org/) A Module Loader for the Web
    + [CrapLoader](https://github.com/gregersrygg/crapLoader)
    + [Writing Modular JavaScript With AMD, CommonJS & ES Harmony](http://addyosmani.com/writing-modular-js/)
    + [Путь JavaScript модуля](http://habrahabr.ru/post/181536/)
    + [Modular JavaScript with RequireJS](http://blog.credera.com/topic/technology-solutions/java/modular-javascript-with-requirejs/)
    + [LABjs & RequireJS: Loading JavaScript Resources the Fun Way](http://msdn.microsoft.com/en-us/magazine//ff943568.aspx)
    + [JavaScript Inheritance and Public/Private members](https://go-left.com/blog/2011/08/js-inheritance/)
    + [Deep dive into the murky waters of script loading](http://www.html5rocks.com/en/tutorials/speed/script-loading/)
+ Package Management
    + [bower](http://bower.io/)
    + [volo](https://github.com/volojs/volo)
    + [parcel](https://github.com/sifteo/parcel) is easy package management using a file server and path conventions, with built in support for Amazon S3. It is designed to encode package metadata, including name, version and OS within a path. The conventions allow this metadata to be queried, without the need for a database.
    + [jam.js](http://jamjs.org/)
+ Image Manipulation
    + [Paintbrush.js](https://github.com/mezzoblue/PaintbrushJS)
    + [Obscura](https://github.com/OiNutter/Obscura)
    + [jCrop](http://deepliquid.com/content/Jcrop.html)
+ Icons
    + [GlyphSearch](http://glyphsearch.com/): A search engine for icons from Font Awesome, Glyphicons, and Ionicons.
    + [Iconic](https://useiconic.com/open/)
    + [Entypo](http://entypo.com/)
    + [IcoMoon](http://icomoon.io/)
    + [Font Custom](http://fontcustom.com/)
    + [Font Awesome](http://fortawesome.github.com/Font-Awesome/): The iconic font designed for use with Twitter Bootstrap
    + [Fontello](https://github.com/fontello/fontello/): Icon fonts generator to get only the required fonts.
    + [Perfect Icons](http://perfecticons.com/): The easiest way to create resolution independent social icons.
+ HTTP
    + [Specification](http://www.w3.org/Protocols/rfc2616/rfc2616.html)
    + [Using CORS](http://www.html5rocks.com/en/tutorials/cors/)
    + [Cross-domain Ajax with Cross-Origin Resource Sharing](http://www.nczonline.net/blog/2010/05/25/cross-domain-ajax-with-cross-origin-resource-sharing/)
+ WebSocket
    + [Specification](http://tools.ietf.org/html/rfc6455)
    + [socket.io](http://socket.io/) aims to make realtime apps possible in every browser and mobile device, blurring the differences between the different transport mechanisms.
    + [engine.io](https://github.com/LearnBoost/engine.io) is the implementation of transport-based cross-browser/cross-device bi-directional communication layer for Socket.IO.
    + [SockJS](https://github.com/sockjs/sockjs-client) is a browser JavaScript library that provides a WebSocket-like object. SockJS gives you a coherent, cross-browser, JavaScript API which creates a low latency, full duplex, cross-domain communication channel between the browser and the web server.
+ Error Handling & Debugging
    + [Tracing.js](https://github.com/ebobby/tracing.js) - JavaScript function tracing.
    + [JavaScript error handling anti-pattern](http://www.nczonline.net/blog/2009/04/28/javascript-error-handling-anti-pattern/)
    + [Tattletale](https://github.com/vimeo/tattletale)
    + [jsconsole](http://jsconsole.com/): injectable remote console.
+ Documentation
    + [DevDocs](http://devdocs.io/) is an all-in-one API documentation reader with a fast, organized, and consistent interface.
    + [dexy](http://www.dexy.it/) is a free-form literate documentation tool for writing any kind of technical document incorporating code.
    + [docco](http://jashkenas.github.com/docco/) is a quick-and-dirty, hundred-line-long, literate-programming-style documentation generator.
    + [styledocco](http://jacobrask.github.io/styledocco/) generates documentation and style guide documents from your stylesheets.
    + [Ronn](https://github.com/rtomayko/ronn) builds manuals. It converts simple, human readable textfiles to roff for terminal display, and also to HTML for the web.
    + [dox](https://github.com/visionmedia/dox) is a JavaScript documentation generator written with node. Dox no longer generates an opinionated structure or style for your docs, it simply gives you a JSON representation, allowing you to use markdown and JSDoc-style tags.
    + [YUIDoc](http://yui.github.com/yuidoc/) is a Node.js application that generates API documentation from comments in source, using a syntax similar to tools like Javadoc and Doxygen.
    + [coddoc](http://doug-martin.github.com/coddoc/) is a jsdoc parsing library. Coddoc is different in that it is easily extensible by allowing users to add tag and code parsers through the use of coddoc.addTagHandler and coddoc.addCodeHandler. coddoc also parses source code to be used in APIs.
    + [sphinx](http://sphinx-doc.org/) a tool that makes it easy to create intelligent and beautiful documentation
    + [Using JSDoc](http://usejsdoc.org/)
    + [Beautiful docs](http://beautifuldocs.com/) is a documentation viewer based on markdown files.
    + [Daux.io](http://daux.io/) is an documentation generator that uses a simple folder structure and Markdown files to create custom documentation on the fly.
+ Windows 8 Style
    + [Metro UI CSS](http://metroui.org.ua/)
    + [BootMetro](http://aozora.github.com/bootmetro/)
    + [metro-bootstrap](http://talkslab.github.com/metro-bootstrap/)
    + [Metro UI Template](http://metro-webdesign.info/)
    + [Droptiles – Metro-Style Web Dashboard](http://www.codeproject.com/Articles/421601/Droptiles-Metro-style-Live-Tiles-powered-Web-Dashb)
    + [Metro JS](http://www.drewgreenwell.com/projects/metrojs)
    + [Windows Metro tiles with JavaScript and CSS3](https://github.com/tholman/tileJs)
    + [Cosmo](http://bootswatch.com/cosmo/)
    + [Video: What Web Developers Need to Know When Building Metro style Apps](http://channel9.msdn.com/Events/TechEd/NorthAmerica/2012/DEV352)
    + [CSS3 Microsoft Modern Buttons](http://ace-subido.github.com/css3-microsoft-metro-buttons/index.html)
    + [Visual Studio 2012 Image Library - 5,000+ Images Downloadable Now](http://dotnet.dzone.com/articles/visual-studio-2012-image)
    + [Metro User Interface Implementation and Resources](http://www.queness.com/post/13493/metro-user-interface-implementation-and-resources)
    + [Windows-8-like animations with CSS3 and jQuery](http://sarasoueidan.com/blog/windows8-animations): a demo made by Sara Soueidan about creating a Modern UI design like in Windows 8.
+ Video & Audio
    + [SublimeVideo](http://sublimevideo.net/): Modular Video Player Framework.
    + [Video.js](http://www.videojs.com/): The open source HTML5 video player.
    + [FlowPlayer](http://flowplayer.org/): The video player for the web.
    + [longtailVideo](http://www.longtailvideo.com/): dual-mode HTML5 & Flash player.
    + [howler.js](http://goldfirestudios.com/blog/104/howler.js-Modern-Web-Audio-JavaScript-Library)
    + [Stratus 2](http://stratus.sc/) soundcloud player
    + [jPlayer](http://jplayer.org/) is the completely free and open source (MIT) media library written in JavaScript.
    + [MediaElement.js](http://mediaelementjs.com/): HTML5 audio and video players in pure HTML and CSS.
    + [audio.js](http://kolber.github.io/audiojs/) is a drop-in javascript library that allows HTML5’s "audio" tag to be used anywhere.
+ Library Collections
    + [Unheap](http://www.unheap.com/): A tidy repository of jQuery plugins
    + [jster](http://jster.net/)
    + [MicroJS](http://microjs.com/) helps you discover the most compact-but-powerful microframeworks.
    + [JSPkg](http://jspkg.com/): reference library and package manager
    + [jquer.in](http://jquer.in/) is a curated collection of jQuery plugins.
    + [JSDB.io](http://www.jsdb.io): great source of the best JavaScript frameworks, plugins, and tools.
+ Other Front End Collections
    + [pineapple.io](http://pineapple.io/): A central hub of Tutorials, Tools and Assets for developers and designers
    + [Frontdesk](https://github.com/miripiruni/frontdesk): Community driven list of useful things for Front End Developers
    + [Front-end Code Standards & Best Practices](http://isobar-idev.github.io/code-standards/) by Roundarch Isobar
    + [Devlinks](http://devlinks.co.uk/) by David Higgins
    + [Life of JS](http://lifeofjs.com/)
+ Chat
    + [XMPP using JSON](https://xmpp-ftw.jit.su/)
    + [Converse.js](http://conversejs.org/) is an open source, webchat client, that runs in the browser and can be integrated into any website.
+ Prototyping
    + [RoughDraft.js](https://github.com/ndreckshage/roughdraft.js)
    + [Video: Style guides are the new Photoshop by Stephen Hay](http://vimeo.com/52851510) + [Slides](http://de.slideshare.net/stephenhay/style-guides-are-the-new-photoshop-fronteers-2012)
    + [fixie](https://github.com/ryhan/fixie)
    + [Holder.js](http://imsky.github.com/holder/)
+ JSON
    + [JSON Query Language](http://jsoniq.org/) is a query and processing language specifically designed for the popular JSON data model.
    + [Oboe.js](https://github.com/jimhigson/oboe.js) makes it really easy to start using json from a response before the ajax request completes; or even if it never completes.
    + [JSONLint](http://jsonlint.com/)
    + [SpahQL](http://danski.github.io/spahql/): fetch deeply-nested data, traverse large trees, query for data based on conditions, make assertions about data.
    + [JSONiq](http://www.jsoniq.org/): query and processing language for JSON.
+ Presentations
    + [Ancesor.js](http://kirkas.ch/ascensor/)
    + [Slideshow.html](http://dmfrancisco.github.com/slideshow.html/)
    + [HTML5 Slideshow](http://www.ravelrumba.com/blog/html5-slideshow/)
    + [reveal.js](https://github.com/hakimel/reveal.js)
    + [html5 Slides by Google](https://code.google.com/p/io-2012-slides/)
    + [Slides](https://github.com/briancavalier/slides)
    + [CSSS](http://lea.verou.me/csss/sample-slideshow.html)
    + [deck.js](http://imakewebthings.com/deck.js/)
    + [controldeck.js](http://controldeck.aws.af.cm/)
    + [impress.js](http://bartaz.github.io/impress.js/)
    + [hyhyhy](https://github.com/MaciejCzyzewski/hyhyhy)
+ Scrolling
    + [AppScroll.js](https://github.com/jakiestfu/AppScroll.js) AppScroll is a tiny (< 100 lines) JS library that fixes the "website dragging" issue caused on iDevices
    + [Scrollpath](http://joelb.me/scrollpath/)
    + [jQuery NiceScroll](http://code.google.com/p/jquery-nicescroll/)
    + [FoldScroll](http://soulwire.github.com/FoldScroll/)
    + [Scrollorama](http://johnpolacek.github.com/scrollorama/)
+ Keyboard
    + [Mousetrap](http://craig.is/killing/mice)
    + [Keypress](http://dmauro.github.com/Keypress/)
    + [konami.js](http://mckamey.github.com/konami-js/)
    + [Keys.js](https://github.com/bitwalker/keys.js)
    + [keymage.js](https://github.com/piranha/keymage)
    + [jwerty](https://github.com/keithamus/jwerty)
+ Tables & DataGrids
    + [Tablecloth.js](http://tableclothjs.com/)
    + [Responsive Data Tables](http://css-tricks.com/responsive-data-tables/)
    + [stacktable.js](http://johnpolacek.github.com/stacktable.js/)
    + [FooTable](http://themergency.com/footable/)
    + [Handsontable](http://handsontable.com/)
    + [Backgrid.js](http://wyuenho.github.com/backgrid)
    + [Gridster](http://gridster.net/)
    + [Flex](http://jsonenglish.com/projects/flex/)
    + [grid-list](https://github.com/uberVU/grid)
+ Security
    + [oAuth Consumer Library](http://oauth.googlecode.com/svn/code/javascript/) by John Kristian
     + [ohauth](https://github.com/gijs/ohauth)
        + [How iD Logs in to OpenStreetMap](http://mapbox.com/osmdev/2013/01/15/oauth-in-javascript/)
    + [JSO - a JavaScript OAuth Library](https://github.com/andreassolberg/jso)
    + [xdoauthproxy](https://code.google.com/p/xdoauthproxy/)
    + [JavaScript Cryptography](http://disattention.com/13/javascript-cryptography/)
    + [JavaScript Crypto Library](http://www.clipperz.com/open_source/javascript_crypto_library)
    + [Stanford JavaScript Crypto Library](http://crypto.stanford.edu/sjcl/)
    + [mozilla / jwcrypto](https://github.com/mozilla/jwcrypto)
    + Critic
        + [JavaScript Cryptography Considered Harmful](http://www.matasano.com/articles/javascript-cryptography/)
        + [Final post on JavaScript crypto](http://rdist.root.org/2010/11/29/final-post-on-javascript-crypto/)
+ Layout
    + [Shapeshift](https://github.com/McPants/jquery.shapeshift) is a plugin which will dynamically arrange a collection of elements into a column grid system similar to Pinterest.
    + [CollagePlus](http://ed-lea.github.io/jquery-collagePlus/): This plugin for jQuery will arrange your images to fit exactly within a container.
    + [Masonry](http://masonry.desandro.com/)  JavaScript Cascading grid layout library
    + [MixItUp](https://mixitup.kunkalabs.com/) jQuery plugin providing animated filtering and sorting.
+ Jobs & Hiring
    + [GitHub Jobs](https://jobs.github.com/)
    + [Authentic Jobs](http://www.authenticjobs.com/)
    + [37signals Job Board](http://jobs.37signals.com/)
    + [Smashing Jobs](http://jobs.smashingmagazine.com/)
    + [Front-end Developer Interview Questions](https://github.com/darcyclarke/Front-end-Developer-Interview-Questions)
    + [Interview This!](https://github.com/ChiperSoft/InterviewThis): A list of questions to ask employers.
    + [Code problems](https://github.com/blakeembrey/code-problems) -- Common code problems solved using JavaScript
    + [StackOverflow Jobs](http://careers.stackoverflow.com/)
    + [CodePen Jobs](http://codepen.io/jobs/)
+ Misc
    + [zip.js](http://gildas-lormeau.github.com/zip.js/)
    + [simpleCart.js](http://simplecartjs.org/)
    + [Mozilla / pdf.js](https://github.com/mozilla/pdf.js)
    + [Aware.js](http://xoxco.com/projects/code/aware/) is a simple jQuery plugin that allows a site to customize and personalize the display of content based on a reader's behavior without requiring login, authentication, or any server-side processing.
    + [How to directly upload files to Amazon S3 from your client side web app](http://codeartists.com/post/36892733572/how-to-directly-upload-files-to-amazon-s3-from-your)
    + [jIO](https://www.j-io.org/) is a client-side JavaScript library to manage documents across multiple storages.
    + [Lo-Dash](http://lodash.com/) - A low-level utility library delivering consistency, customization, performance, and extra features.
    + [Subtle Patterns](http://subtlepatterns.com/)


## License

<a rel="license" href="http://creativecommons.org/licenses/by/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by/4.0/88x31.png" /></a><br />This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by/4.0/">Creative Commons Attribution 4.0 International License</a>.

Please provide a link back to this repository. This is not necessary for GitHub forks.

## Donate

[![Beerpay](https://beerpay.io/dypsilon/frontend-dev-bookmarks/badge.svg?style=flat-square)](https://beerpay.io/dypsilon/frontend-dev-bookmarks)
